@@ -182,11 +182,29 @@ class BackTestEngine:
 
         self.__executeInstance.init(self.__backTestContext)
 
+        _amountChangeList = []
         _startTimeStamp = self.__startTimeMills
         _endTimeStamp = self.__endTimeStampMills
         _executePeriod = self.__backTestContext.getExecutePeriod()
+        _periodMills = self.resolveExecutePeriodMills(_executePeriod)
 
         while True:
+
+            _positions = self.__backTestContext.getPositions()
+            _startTotalAmount = decimal.Decimal('0')
+            _endTotalAmount = decimal.Decimal('0')
+
+            for _position in _positions.values():
+                _tc = _position.tc
+                _symbol = _position.symbol
+                _startKlines = self.__dataSource.queryKline(_tc, _symbol, KlinePeriod.MIN_1, startTimeMills=_startTimeStamp, limit=1)
+                if _startKlines:
+                    _price = _startKlines[0].openingPrice
+                else:
+                    raise Exception("kline from " + str(_startTimeStamp) + " not found")
+
+                _startTotalAmount = _startTotalAmount + (_position.remainAmount + _position.remainHolding * _price)
+
             try:
                 self.__executeInstance.executeStopLoss(self.__backTestContext)
             except Exception as e:
@@ -198,13 +216,36 @@ class BackTestEngine:
             try:
                 self.__backTestContext.setExecutingTimeMills(_startTimeStamp)
                 self.__executeInstance.execute(self.__backTestContext)
+
+                _positions = self.__backTestContext.getPositions()
+                _endMills = _startTimeStamp + _periodMills - 1
+
+                for _position in _positions.values():
+                    _tc = _position.tc
+                    _symbol = _position.symbol
+                    _endKlines = self.__dataSource.queryLatestKline(_tc, _symbol, KlinePeriod.MIN_1, endTimeMills=_endMills, limit=1)
+
+                    if _endKlines:
+                        _price = _endKlines[0].closingPrice
+                    else:
+                        raise Exception("kline to " + str(_endMills) + " not found")
+
+                    _endTotalAmount = _endTotalAmount + (_position.remainAmount + _position.remainHolding * _price)
+
+                _amountChangeList.append(
+                    {
+                        "timeMills": _startTimeStamp,
+                        "startTotalAmount": _startTotalAmount, "endTotalAmount": _endTotalAmount, "profitRate": (_endTotalAmount - _startTotalAmount) / _startTotalAmount * 100
+                    }
+                )
+
             except Exception as e:
                 traceback.print_exc()
 
             if _startTimeStamp >= _endTimeStamp:
                 break
             else:
-                _startTimeStamp = _startTimeStamp + self.resolveExecutePeriodMills(_executePeriod)
+                _startTimeStamp = _startTimeStamp + _periodMills
 
         try:
             self.__executeInstance.destroy(self.__backTestContext)
@@ -213,7 +254,7 @@ class BackTestEngine:
 
         # 生产回测结果
         _backTestResult = BackTestResult(
-            self.__startDate, self.__endDate, self.__backTestContext.backTestOrders, self.__backTestContext.getPositions())
+            self.__startDate, self.__endDate, self.__backTestContext.backTestOrders, self.__backTestContext.getPositions(), _amountChangeList)
 
         return _backTestResult
 
